@@ -2,44 +2,42 @@ import os
 import pandas as pd
 import json
 import gzip
-
 from pathlib import Path
 from io import StringIO
 
 from spectroview import PLOT_STYLES, LEGEND_LOCATION, ICON_DIR
 
-from spectroview.components.utils import view_df, show_alert, copy_fig_to_clb
-from spectroview.components.widget_filter import FilterWidget
-from spectroview.components.graph import Graph
-from spectroview.components.utils import CustomizedPalette
+from spectroview.modules.utils import view_df, show_alert, copy_fig_to_clb
+from spectroview.modules.df_filter import DataframeFilter
+from spectroview.modules.graph import Graph
+from spectroview.modules.utils import CustomizedPalette
 
-from PySide6.QtWidgets import QFileDialog, QDialog, QVBoxLayout, QListWidgetItem, QMdiSubWindow, QCheckBox, QMessageBox
+from PySide6.QtWidgets import QWidget, QFileDialog, QDialog, QVBoxLayout, QListWidgetItem, QMdiSubWindow, QCheckBox, QMessageBox,QLabel
 from PySide6.QtCore import Qt, QTimer, Signal, QSize
 from PySide6.QtGui import  QIcon, Qt
 
+
 class Graphs(QDialog):
-    """
-    This class provides a GUI for plotting graphs based on selected dataframes,
-    applying filters, customizing graph properties, and managing graph
-    instances.
-    """
-    def __init__(self, settings, ui, common):
+    """This class provides a GUI for plotting graphs/figures."""
+    def __init__(self, settings, ui):
         super().__init__()
         self.ui = ui
         self.settings = settings
-        self.common = common
+        
         self.setWindowTitle("Graph Plot")
 
         # DATAFRAME
         self.original_dfs = {}
-        self.sel_df = None
+        self.selected_df = None
         self.ui.btn_view_df_3.clicked.connect(self.show_df)
         self.ui.dfs_listbox.itemSelectionChanged.connect(self.update_gui)
+        
+        
         self.ui.btn_remove_df_2.clicked.connect(self.remove_df)
         self.ui.btn_save_df_2.clicked.connect(self.save_df_to_excel)
 
         # FILTER
-        self.filter = FilterWidget(self.sel_df)
+        self.filter = DataframeFilter(self.selected_df)
         self.ui.filter_widget_layout.addWidget(self.filter.gb_filter_widget)
         self.filtered_df = None
 
@@ -48,6 +46,8 @@ class Graphs(QDialog):
         self.graph_id = 0  # Initialize graph number
         # Add a graph
         self.ui.btn_add_graph.clicked.connect(self.plotting)
+        self.ui.btn_add_multi_wafer_plots.clicked.connect(self.plotting_multi_wafer_plots)
+
         self.ui.btn_get_limits.clicked.connect(self.set_current_limits)
         self.ui.btn_clear_limits.clicked.connect(self.clear_limits)
         # Update an existing graph
@@ -77,16 +77,26 @@ class Graphs(QDialog):
             else:
                 icon = QIcon()  # Fallback in case the icon is missing
             self.ui.cbb_plotstyle.addItem(icon, style)
+        self.ui.cbb_plotstyle.setToolTip("Select Plot Style")
+        self.ui.cbb_plotstyle.currentIndexChanged.connect(self.auto_select_XY_for_wafer_plot)
 
         self.ui.cbb_legend_loc.addItems(LEGEND_LOCATION)
-
+        
         # Track selected sub-window
         self.ui.mdiArea.subWindowActivated.connect(self.on_selected_graph)
         self.ui.cbb_graph_list.currentIndexChanged.connect(
             self.select_sub_window_from_combo_box)
 
         self.ui.btn_minimize_all.clicked.connect(self.minimize_all_graph)
-
+                 
+    def update_gui(self):
+        """Update the GUI elements based on the selected dataframe"""
+        self._update_cbb()
+        self.show_wafer_slot_selector()
+        self.auto_select_XY_for_wafer_plot()
+        self.selected_df = self.get_sel_df()
+        
+    
     def open_dfs(self, dfs=None, file_paths=None):
         """Open and load dataframes from Excel files."""
         if self.original_dfs is None:
@@ -114,9 +124,7 @@ class Graphs(QDialog):
         self.update_dfs_list()
 
     def update_dfs_list(self):
-        """
-        This method updates the dataframe listbox with current dataframes.
-        """
+        """Update the listbox showing available dataframes."""
         current_row = self.ui.dfs_listbox.currentRow()
         self.ui.dfs_listbox.clear()
         df_names = list(self.original_dfs.keys())
@@ -170,8 +178,11 @@ class Graphs(QDialog):
         y = self.ui.cbb_y_2.currentText()
         z = self.ui.cbb_z_2.currentText()
 
+        graph.xlogscale = self.ui.xaxis_log_scale.isChecked()
+        graph.ylogscale = self.ui.yaxis_log_scale.isChecked()
+
         # Check if z has changed and reset legend_properties if needed
-        self.is_z_changed(graph)
+        self._is_z_changed(graph)
 
         graph.x = x
         if len(graph.y) == 0:
@@ -254,18 +265,148 @@ class Graphs(QDialog):
         graph_dialog.setWindowTitle(text)
 
         # Plot action
-        QTimer.singleShot(100, self.plot_action)
+        QTimer.singleShot(100, self._plot_action)
+        QTimer.singleShot(200, self.customize_legend)
+        
+    def plotting_multi_wafer_plots(self):
+        """ Plot multiple wafer plots based on selected slots (via checkboxes)."""
+        sel_df = self.selected_df
+        if sel_df is None:
+            show_alert("No dataframe is selected. Please select a dataframe before plotting.")
+            return
+
+        # Only relevant for wafer plots
+        self.ui.cbb_plotstyle.setCurrentIndex(6)
+
+        if self.ui.cbb_z_2.currentText().strip().lower() == "none":
+            show_alert("No Z value selected. Please choose a data column for the wafer map.")
+            return
+
+    
+        # Collect checked slots from the slot selector
+        checked_slots = [cb.text() for cb in getattr(self, 'slot_checkboxes', []) if cb.isChecked()]
+        if not checked_slots:
+            show_alert("No wafer slots are selected. Please check at least one slot before plotting.")
+            return
+
+        # Base filters from GUI
+        base_filters = self.filter.get_current_filters() or []
+
+        # Helper to produce a canonical expression string for a slot number
+        def slot_expression(n):
+            return f"Slot == {n}"
+
+        # Helper: merge base_filters with (Slot == n) ensuring only this slot is active
+        def merged_filters_with_slot(slot_num):
+            expr_to_activate = slot_expression(slot_num)
+            merged = []
+            slot_found = False
+            for f in base_filters:
+                f_copy = dict(f)
+                if "Slot" in f_copy.get("expression", ""):
+                    # deactivate all Slot filters first
+                    f_copy["state"] = False
+                    if f_copy["expression"] == expr_to_activate:
+                        f_copy["state"] = True
+                        slot_found = True
+                merged.append(f_copy)
+            if not slot_found:
+                # append the active Slot filter if not present
+                merged.append({"expression": expr_to_activate, "state": True})
+            return merged
+
+        # For each checked slot, create and plot a new Graph
+        for slot_text in checked_slots:
+            try:
+                slot_num = int(slot_text)
+            except Exception:
+                slot_num = slot_text
+
+            # Build filters for this slot plot
+            new_filters = merged_filters_with_slot(slot_num)
+
+            # Determine a new graph_id same way plotting() does
+            available_ids = [i for i in range(1, len(self.plots) + 2) if i not in self.plots]
+            graph_id = min(available_ids) if available_ids else len(self.plots) + 1
+
+            # Create and register the Graph object
+            graph = Graph(graph_id=graph_id)
+            self.plots[graph.graph_id] = graph
+
+            # Collect GUI properties
+            graph.plot_style = self.ui.cbb_plotstyle.currentText()
+            title = self.ui.lbl_plot_title.text()
+            graph.plot_title = title if title != "None" else None
+            current_df_name = self.ui.dfs_listbox.currentItem().text() if self.ui.dfs_listbox.currentItem() else None
+            graph.df_name = current_df_name
+            graph.filters = new_filters
+
+            x = self.ui.cbb_x_2.currentText()
+            y = self.ui.cbb_y_2.currentText()
+            z = self.ui.cbb_z_2.currentText()
+
+            if new_filters != graph.filters:
+                graph.legend_properties = []
+
+            graph.x = x
+            if len(graph.y) == 0:
+                graph.y.append(y)
+            else:
+                graph.y[0] = y
+            graph.z = z if z != "None" else None
+
+            graph.color_palette = self.cbb_palette.currentText()
+            graph.wafer_size = float(self.ui.lbl_wafersize.text())
+            graph.wafer_stats = self.ui.cb_wafer_stats.isChecked()
+            graph.dpi = float(self.ui.spb_dpi.text())
+            graph.legend_visible = self.ui.cb_legend_visible.isChecked()
+            graph.legend_location = self.ui.cbb_legend_loc.currentText()
+            graph.legend_outside = self.ui.cb_legend_outside.isChecked()
+            graph.grid = self.ui.cb_grid.isChecked()
+            graph.trendline_order = float(self.ui.spb_trendline_oder.text())
+            graph.show_trendline_eq = self.ui.cb_trendline_eq.isChecked()
+            graph.show_bar_plot_error_bar = self.ui.cb_show_err_bar_plot.isChecked()
+            graph.join_for_point_plot = self.ui.cb_join_for_point_plot.isChecked()
+
+            # Create the plotting widget and subwindow
+            graph.create_plot_widget(graph.dpi)
+            graph_dialog = QDialog(self)
+            layout = QVBoxLayout()
+            layout.setContentsMargins(0, 0, 0, 0)
+            layout.addWidget(graph)
+            graph_dialog.setLayout(layout)
+            graph_dialog.setContentsMargins(2, 2, 2, 0)
+
+            sub_window = MdiSubWindow(graph_id, self.ui.lbl_figsize, mdi_area=self.ui.mdiArea)
+            sub_window.setWidget(graph_dialog)
+            sub_window.closed.connect(lambda graph_id=graph.graph_id: self.delete_graph(graph_id))
+            sub_window.resize(graph.plot_width, graph.plot_height)
+            self.ui.mdiArea.addSubWindow(sub_window)
+            sub_window.show()
+
+            # Set window title and add to combobox
+            text = f"{graph.graph_id}-{graph.plot_style}_plot: [{x}] - [{y}] - [{z}]"
+            graph_dialog.setWindowTitle(text)
+            self.add_graph_list_to_combobox()
+
+            # Apply filters and plot
+            filtered_df = self.apply_filters(self.selected_df, graph.filters)
+            try:
+                if graph.plot_style == 'wafer':
+                    graph.create_plot_widget(graph.dpi, graph.graph_layout)
+                    graph.plot(filtered_df)
+                else:
+                    graph.plot(filtered_df)
+            except Exception as e:
+                show_alert(f"Failed plotting slot {slot_num}: {e}")
+
         QTimer.singleShot(200, self.customize_legend)
 
-    def plot_action(self):
-        """
-        Perform the plot action for the selected graph.
-        This method fetches the selected graph, applies filters, and triggers
-        the actual plotting.
-        """
+    def _plot_action(self):
+        """Perform the actual plotting of the graph."""
         graph, graph_dialog, sub_window = self.get_sel_graph()
-        self.filtered_df = self.apply_filters(self.sel_df, graph.filters)
-        # print(f"self.sel_df {self.sel_df}")
+        self.filtered_df = self.apply_filters(self.selected_df, graph.filters)
+      
         if graph:
             if graph.plot_style == 'wafer':
                 graph.create_plot_widget(graph.dpi, graph.graph_layout)
@@ -273,7 +414,7 @@ class Graphs(QDialog):
             else:
                 graph.plot(self.filtered_df)
 
-    def is_z_changed(self, graph):
+    def _is_z_changed(self, graph):
         """Check if z-axis value has changed from the current graph settings"""
         current_z = self.ui.cbb_z_2.currentText()
         if current_z != graph.z:
@@ -285,7 +426,7 @@ class Graphs(QDialog):
         """ Show all legend's properties in GUI for customization"""
         graph, graph_dialog, sub_window = self.get_sel_graph()
         main_layout = self.ui.main_layout
-        graph.customize_legend_via_gui(main_layout)
+        graph.customize_legend_widget(main_layout)
 
     def set_current_limits(self):
         """Get and set current scales for selected plot"""
@@ -341,7 +482,7 @@ class Graphs(QDialog):
                 self.ui.dfs_listbox.setCurrentRow(index)
 
             # Reflect filter's states in the listbox
-            self.reflect_filters_to_gui(graph)
+            self._reflect_filters_to_gui(graph)
 
             # Update combobox selections
             x = self.ui.cbb_x_2.findText(graph.x)
@@ -355,6 +496,10 @@ class Graphs(QDialog):
             self.ui.cbb_y3_2.setCurrentIndex(y3 if y3 != -1 else 0)
             self.ui.cbb_z_2.setCurrentIndex(z if z != -1 else 0)
 
+            self.ui.xaxis_log_scale.setChecked(graph.xlogscale)
+            self.ui.yaxis_log_scale.setChecked(graph.ylogscale)
+
+
             # WAFER
             self.ui.lbl_wafersize.setText(str(graph.wafer_size))
             self.ui.cb_wafer_stats.setChecked(graph.wafer_stats)
@@ -426,7 +571,7 @@ class Graphs(QDialog):
             # Show legends on GUI for customization
             self.customize_legend()
 
-    def reflect_filters_to_gui(self, sel_graph):
+    def _reflect_filters_to_gui(self, sel_graph):
         """Reflect the state of filters associated with a graph to the GUI"""
         # Clear the existing items and uncheck them
         for index in range(self.filter.filter_listbox.count()):
@@ -463,12 +608,7 @@ class Graphs(QDialog):
                 self.filter.filter_listbox.addItem(item)
                 self.filter.filter_listbox.setItemWidget(item, checkbox)
 
-    def update_gui(self):
-        """Update the GUI elements based on the selected dataframe"""
-        self.update_cbb()
-        self.sel_df = self.get_sel_df()
-
-    def update_cbb(self):
+    def _update_cbb(self):
         """Populate columns of selected data to comboboxes"""
         sel_df = self.get_sel_df()
         if sel_df is not None:
@@ -523,12 +663,12 @@ class Graphs(QDialog):
         if sel_item is not None:
             sel_df_name = sel_item.text()
             if sel_df_name in self.original_dfs:
-                self.sel_df = self.original_dfs[sel_df_name]
+                self.selected_df = self.original_dfs[sel_df_name]
             else:
-                self.sel_df = None 
+                self.selected_df = None 
         else:
-            self.sel_df = None 
-        return self.sel_df
+            self.selected_df = None 
+        return self.selected_df
 
     def remove_df(self):
         """
@@ -569,25 +709,14 @@ class Graphs(QDialog):
     def show_df(self):
         """This method displays the selected dataframe in a new window"""
         current_filters = self.filter.get_current_filters()
-        current_df = self.apply_filters(self.sel_df, current_filters)
+        current_df = self.apply_filters(self.selected_df, current_filters)
         if current_df is not None:
             view_df(self.ui.tabWidget, current_df)
         else:
             show_alert("No fit dataframe to display")
 
     def apply_filters(self, df=None, filters=None):
-        """
-        Apply filters to the specified dataframe or the currently selected
-        dataframe.
-
-        Args:
-            df (pd.DataFrame, optional): Dataframe to apply filters to.
-            filters (list, optional): List of filters to apply.
-
-        Returns:
-            pd.DataFrame: Filtered dataframe.
-
-        """
+        """Apply filters to the selected dataframe and return the filtered dataframe."""
         if df is None:
             sel_df = self.get_sel_df()
         else:
@@ -618,10 +747,6 @@ class Graphs(QDialog):
                 self.ui.cbb_graph_list.count() - 1)
 
     def select_sub_window_from_combo_box(self):
-        """
-        This method selects and displays a graph based on the user selection
-        in the combobox.
-        """
         graph_title = self.ui.cbb_graph_list.currentText()
         for sub_window in self.ui.mdiArea.subWindowList():
             graph_dialog = sub_window.widget()
@@ -636,22 +761,86 @@ class Graphs(QDialog):
                     self.ui.mdiArea.setActiveSubWindow(sub_window)
                     return
 
+    def auto_select_XY_for_wafer_plot(self):
+        """Auto select X and Y columns if 'wafer' plot style is selected."""
+        if self.ui.cbb_plotstyle.currentText().lower() == 'wafer':
+            # Auto select X and Y columns if 'X' and 'Y' exist in dataframe
+            sel_df = self.get_sel_df()
+            if sel_df is not None:
+                columns = sel_df.columns.tolist()
+                if 'X' in columns and 'Y' in columns:
+                    self.ui.cbb_x_2.setCurrentText('X')
+                    self.ui.cbb_y_2.setCurrentText('Y')
     
+    def show_wafer_slot_selector(self):
+        """Build UI for slot selector checkboxes if 'Slot' column exists in the selected dataframe."""
+        layout = self.ui.layout_slotselector 
+        # Clear existing widgets
+        while layout.count():
+            child = layout.takeAt(0)
+            if child.widget():
+                child.widget().deleteLater()
 
+        sel_df = self.selected_df
+        if sel_df is not None and 'Slot' in sel_df.columns:
+            unique_slots = sorted(sel_df['Slot'].dropna().unique())
+            if not unique_slots:
+                return
+            # --- Add QLabel before the "Select All" checkbox ---
+            label = QLabel("Select wafer slot:")
+            label.setStyleSheet("font-weight: bold;")  
+            layout.addWidget(label, 0, 0, 1, 3)
+
+            # "Select All" checkbox (placed on first row)
+            self.select_all_checkbox = QCheckBox("Select All")
+            self.select_all_checkbox.setChecked(True)
+            layout.addWidget(self.select_all_checkbox, 0, 3, 1, 6)
+
+            # Create individual slot checkboxes
+            self.slot_checkboxes = []
+            row, col = 1, 0
+            for slot in unique_slots:
+                cb = QCheckBox(str(slot))
+                cb.setChecked(True)
+                layout.addWidget(cb, row, col)
+                self.slot_checkboxes.append(cb)
+
+                col += 1
+                if col >= 9:  # wrap after 9 columns
+                    col = 0
+                    row += 1
+
+            # Connect signals
+            self.select_all_checkbox.stateChanged.connect(self.toggle_all_slots)
+            for cb in self.slot_checkboxes:
+                cb.stateChanged.connect(self.update_select_all_status)
+
+    def toggle_all_slots(self, checked: bool):
+        """Toggle all slot checkboxes when Select All is changed."""
+        for cb in getattr(self, 'slot_checkboxes', []):
+            cb.blockSignals(True)
+            cb.setChecked(checked)
+            cb.blockSignals(False)
+        if hasattr(self, 'select_all_checkbox'):
+            self.select_all_checkbox.setChecked(checked)
+
+    def update_select_all_status(self):
+        """Update Select All checkbox if any individual slot checkbox is unchecked."""
+        # compute new desired state
+        all_checked = all(cb.isChecked() for cb in getattr(self, 'slot_checkboxes', []))
+        if hasattr(self, 'select_all_checkbox'):
+            self.select_all_checkbox.blockSignals(True)
+            self.select_all_checkbox.setChecked(all_checked)
+            self.select_all_checkbox.blockSignals(False)
+            
     def minimize_all_graph(self):
-        """
-        This method minimizes all open graph sub-windows.
-        """
         for sub_window in self.ui.mdiArea.subWindowList():
             sub_window.showMinimized()
 
     def clear_env(self):
-        """
-        This method reinit all attributes.
-        """
         # Clear original dataframes
         self.original_dfs = {}
-        self.sel_df = None
+        self.selected_df = None
         self.filtered_df = None
         self.filter.filters = []
 
@@ -840,14 +1029,14 @@ class Graphs(QDialog):
                     sub_window.resize(graph.plot_width, graph.plot_height)
                     sub_window.show()
 
-                    self.plot_action()
+                    self._plot_action()
                     
                 self.filter.upd_filter_listbox()
                 self.add_graph_list_to_combobox()
 
         except Exception as e:
-            show_alert(f"Error loading saved work (Visulization Tab): {e}")
-            # print(f"Error loading work: {e}")
+            show_alert(f"Error loading saved work (Graphs Tab): {e}")
+            print(f"Error loading work: {e}")
 
     def delete_graph(self, graph_id):
         """Delete the specified graph from the plots dictionary by graph_id"""
@@ -876,12 +1065,6 @@ class MdiSubWindow(QMdiSubWindow):
     """
     Custom class of QMdiSubWindow to prevent automatic selection of other windows
     when one subwindow is closed.
-
-    Attributes:
-    closed (Signal): Signal emitted when the subwindow is closing, carrying
-    the graph ID.
-    graph_id (int): ID associated with the graph in the subwindow.
-    figsize_label (QLabel): QLabel used to display the size of the subwindow.
     """
     closed = Signal(int)
 
@@ -916,5 +1099,4 @@ class MdiSubWindow(QMdiSubWindow):
         # Prevent the window from being focused (optional)
         if not self.mdi_area.activeSubWindow():
             self.mdi_area.setActiveSubWindow(None)
-        super().focusInEvent(event)
-
+        super().focusInEvent(event)
\ No newline at end of file
