@@ -5,25 +5,23 @@ import numpy as np
 import pandas as pd
 import json
 import gzip
-
 from io import StringIO
 from copy import deepcopy
 from pathlib import Path
 
-from spectroview import FIT_METHODS
-from spectroview.components.utils import calc_area, view_df, show_alert, spectrum_to_dict, dict_to_spectrum, baseline_to_dict, dict_to_baseline, save_df_to_excel
-from spectroview.components.utils import FitThread, FitModelManager, CustomizedListWidget, CustomizedSpectra
-from spectroview.components.widget_df_table import DataframeTableWidget
-from spectroview.components.widget_mapview import MapViewWidget
-from spectroview.components.widget_spectraview import SpectraViewWidget
-from spectroview.components.widget_peaktable import PeakTableWidget
-from spectroview.components.graph import Graph
+from spectroview.modules.utils import calc_area, view_df, show_alert, spectrum_to_dict, dict_to_spectrum, baseline_to_dict, dict_to_baseline, save_df_to_excel, replace_peak_labels, quadrant, zone, view_text
+from spectroview.modules.utils import FitThread, CustomizedListWidget, Spectra, Spectrum
+from spectroview.modules.df_table import DataframeTable
+from spectroview.modules.map_viewer import MapViewer
+from spectroview.modules.spectra_viewer import SpectraViewer
+from spectroview.modules.peak_table import PeakTable
+from spectroview.modules.graph import Graph
+from spectroview.modules.fit_model_manager import FitModelManager
 
 from spectroview.main_tabs.graphs import MdiSubWindow
 
 from lmfit import fit_report
 
-from fitspy.spectrum import Spectrum
 from fitspy.core.utils import closest_index
 
 from PySide6.QtWidgets import QFileDialog, QMessageBox, QApplication, QListWidgetItem, QDialog, QVBoxLayout
@@ -31,38 +29,33 @@ from PySide6.QtGui import QColor
 from PySide6.QtCore import Qt, QFileInfo, QTimer, QObject
 
 class Maps(QObject):
-    """
-    Class manages the GUI interactions and operations related to spectra
-    fittings,
-    and visualization of fitted data within 'Maps' TAB of the application.
-    """
-
-    def __init__(self, settings, ui, spectrums, common, visu, app_settings):
+    """Class manages the GUI interactions of Maps Tab."""
+    def __init__(self, settings, ui, spectrums, graphs, app_settings):
         super().__init__()
         self.settings = settings
-        self.app_settings = app_settings
+        self.app_settings=app_settings
+
         self.ui = ui
-        self.visu = visu
+        self.graphs = graphs
         self.spectrums_tab = spectrums
-        self.common = common
 
         self.loaded_fit_model = None
-        self.current_fit_model = None
+        self.copied_fit_model = None
         self.maps = {}  # list of opened maps data
-        self.spectrums = CustomizedSpectra()
+        self.spectrums = Spectra()
         
          # Initialize SpectraViewWidget
-        self.spectra_widget = SpectraViewWidget(self)
-        self.ui.fig_canvas_layout_2.addWidget(self.spectra_widget.canvas)
-        self.ui.toolbar_layout_2.addWidget(self.spectra_widget.control_widget) 
+        self.spectra_viewer = SpectraViewer(self)
+        self.ui.fig_canvas_layout_2.addWidget(self.spectra_viewer.canvas)
+        self.ui.toolbar_layout_2.addWidget(self.spectra_viewer.control_widget) 
         self.ui.cbb_fit_models.currentIndexChanged.connect(self.update_peak_model)
         
          # Initialize PeakTable
-        self.peak_table = PeakTableWidget(self, self.ui.peak_table1, self.ui.cbb_layout_2)
+        self.peak_table = PeakTable(self, self.ui.peak_table1, self.ui.cbb_layout_2)
         
          # Initialize Dataframe Table
         self.df_fit_results = None
-        self.df_table = DataframeTableWidget(self.ui.layout_df_table)
+        self.df_table = DataframeTable(self.ui.layout_df_table)
         
         # Initialize QListWidget for spectra list
         self.ui.spectra_listbox = CustomizedListWidget()
@@ -76,35 +69,28 @@ class Maps(QObject):
         self.delay_timer.timeout.connect(self.plot)
 
         # Map_view_Widget
-        self.map_plot = MapViewWidget(self, self.app_settings)
-        self.map_plot.spectra_listbox= self.ui.spectra_listbox
-        self.ui.map_layout.addWidget(self.map_plot.widget)
-        self.map_plot.btn_extract_profile.clicked.connect(self.plot_extracted_profile)
+        self.map_viewer = MapViewer(self, self.app_settings)
+        self.map_viewer.spectra_listbox= self.ui.spectra_listbox
+        self.ui.map_layout.addWidget(self.map_viewer.widget)
+        self.map_viewer.btn_extract_profile.clicked.connect(self.plot_extracted_profile)
         
         ## Update spectra_listbox when selecting maps via MAPS LIST
         self.ui.maps_listbox.itemSelectionChanged.connect(self.upd_spectra_list)
         
-        # BASELINE
-        self.setup_baseline_controls()
-        
-        self.ui.cbb_fit_methods.addItems(FIT_METHODS)
-        self.ui.btn_send_to_viz2.clicked.connect(self.send_df_to_viz)
-
         # Peak correction
         self.ui.btn_xrange_correction_2.clicked.connect(self.xrange_correction)
         self.ui.btn_undo_correction_2.clicked.connect(lambda: self.undo_xrange_correction())
         
+        # BASELINE
+        self.setup_baseline_controls()
+        
+        self.ui.btn_send_to_viz2.clicked.connect(self.send_df_to_viz)
 
-        # FITMODEL FOLDER
-        self.fit_model_manager = FitModelManager(self.settings)
-        self.fit_model_manager.default_model_folder = self.settings.value(
-            "default_model_folder", "")
-        self.ui.l_defaut_folder_model.setText(
-            self.fit_model_manager.default_model_folder)
-        ## Show available fit models
-        QTimer.singleShot(0, self.populate_available_models)
-        self.ui.btn_refresh_model_folder.clicked.connect(
-            self.populate_available_models)      
+        # FIT MODEL MANAGER
+        self.fit_model_manager = FitModelManager()
+        self.ui.horizontalLayout_52.addWidget(self.fit_model_manager)
+        self.fit_model_manager.connect_apply(self.apply_model_fnc_handler)
+         
 
     def setup_baseline_controls(self):
         self.ui.cb_attached.stateChanged.connect(self.refresh_gui)
@@ -126,7 +112,6 @@ class Maps(QObject):
     
     def open_hyperspectra(self, maps=None, file_paths=None):
         """Open hyperspectral data"""
-
         if self.maps is None:
             self.maps = {}
         if maps:
@@ -212,8 +197,6 @@ class Maps(QObject):
                 spectrum.x0 = np.asarray(x_values)
                 spectrum.y = np.asarray(y_values)
                 spectrum.y0 = np.asarray(y_values)
-                spectrum.is_corrected = False
-                spectrum.correction_value = 0
                 spectrum.baseline.mode = "Linear"
                 spectrum.baseline.sigma = 5
                 self.spectrums.append(spectrum)
@@ -226,17 +209,10 @@ class Maps(QObject):
             if sel_spectra is None:
                 _, sel_spectra = self.get_spectrum_object()
             
-            # Restore to original values
-            self.undo_xrange_correction(sel_spectra)
             for spectrum in sel_spectra:
-                # Correction action
-                correction_value = (520.7 - ref_value)
-                uncorrectted_x = deepcopy(spectrum.x)
-                uncorrectted_x0 = deepcopy(spectrum.x0)
-                spectrum.x = uncorrectted_x + correction_value
-                spectrum.x0 = uncorrectted_x0 + correction_value
-                spectrum.correction_value = correction_value
-                spectrum.is_corrected = True
+                new_xcorrection_value = 520.7 - ref_value
+                print(f"Applying x range correction of {new_xcorrection_value} for spectrum {spectrum.fname}")
+                spectrum.apply_xcorrection(new_xcorrection_value)
 
             QTimer.singleShot(100, self.upd_spectra_list)
 
@@ -249,14 +225,8 @@ class Maps(QObject):
         if sel_spectra is None:
             _, sel_spectra = self.get_spectrum_object()
         for spectrum in sel_spectra:
-            if spectrum.is_corrected:
-                # Restore original X values
-                correctted_x=deepcopy(spectrum.x)
-                correctted_x0=deepcopy(spectrum.x0)
-                spectrum.x = correctted_x - spectrum.correction_value
-                spectrum.x0 = correctted_x0 - spectrum.correction_value
-                spectrum.correction_value = 0
-                spectrum.is_corrected = False
+            spectrum.undo_xcorrection()
+
         QTimer.singleShot(100, self.upd_spectra_list)
 
     def view_fit_results_df(self):
@@ -316,130 +286,79 @@ class Maps(QObject):
                 names.append(name)
             self.df_fit_results = self.df_fit_results.iloc[:,list(np.argsort(names, kind='stable'))]
             # Replace peak_label
-            columns = [self.common.replace_peak_labels(self.current_fit_model, column) for column in self.df_fit_results.columns]
+            columns = [replace_peak_labels(self.copied_fit_model, column) for column in self.df_fit_results.columns]
             self.df_fit_results.columns = columns
 
-            map_type = self.map_plot.cbb_map_type.currentText()
+            map_type = self.map_viewer.cbb_map_type.currentText()
             if map_type !='2Dmap':
                 # DIAMETER
-                radius = self.map_plot.get_wafer_radius(map_type)
+                radius = self.map_viewer.get_wafer_radius(map_type)
                 # QUADRANT
-                self.df_fit_results['Quadrant'] = self.df_fit_results.apply(
-                    self.common.quadrant, axis=1)
+                self.df_fit_results['Quadrant'] = self.df_fit_results.apply(quadrant, axis=1)
                 # ZONE
-                self.df_fit_results['Zone'] = self.df_fit_results.apply(
-                    lambda row: self.common.zone(row, radius), axis=1)
+                self.df_fit_results['Zone'] = self.df_fit_results.apply(lambda row: zone(row, radius), axis=1)
             else: 
                 pass
         self.df_table.show(self.df_fit_results)
         
-        self.map_plot.df_fit_results = self.df_fit_results
-        self.map_plot.populate_z_values_cbb()
+        self.map_viewer.df_fit_results = self.df_fit_results
+        self.map_viewer.populate_z_values_cbb()
         
     def update_peak_model(self):
         """Update the peak model in the SpectraViewWidget based on combobox selection."""
         selected_model = self.ui.cbb_fit_models.currentText()
-        self.spectra_widget.set_peak_model(selected_model)
+        self.spectra_viewer.set_peak_model(selected_model)
 
-    def set_default_model_folder(self, folder_path=None):
-        """Define a default folder containing fit models."""
-        if not folder_path:
-            folder_path = QFileDialog.getExistingDirectory(None,
-                                                           "Select Default "
-                                                           "Folder",
-                                                           options=QFileDialog.ShowDirsOnly)
-
-        if folder_path:
-            self.fit_model_manager.set_default_model_folder(folder_path)
-            # Save selected folder path back to QSettings
-            self.settings.setValue("default_model_folder", folder_path)
-            self.ui.l_defaut_folder_model.setText(
-                self.fit_model_manager.default_model_folder)
-            QTimer.singleShot(0, self.populate_available_models)
-
-    def populate_available_models(self):
-        """Populate available fit models in the combobox"""
-        # Scan default folder and populate available models in the combobox
-        self.fit_model_manager.scan_models()
-        self.available_models = self.fit_model_manager.get_available_models()
-        self.ui.cbb_fit_model_list.clear()
-        self.ui.cbb_fit_model_list.addItems(self.available_models)
-
-    def upd_model_cbb_list(self):
-        """
-        Update and populate the model list in the combobox.
-
-        Updates the list of models in the combobox based on the default model
-        folder.
-        """
-        current_path = self.fit_model_manager.default_model_folder
-        self.set_default_model_folder(current_path)
-
-    def load_fit_model(self, fname_json=None):
-        """Load a pre-created fit model"""
-        self.fname_json = fname_json
-        self.upd_model_cbb_list()
-        if not self.fname_json:
-            options = QFileDialog.Options()
-            options |= QFileDialog.ReadOnly
-            selected_file, _ = QFileDialog.getOpenFileName(self.ui,
-                                                           "Select JSON Model "
-                                                           "File",
-                                                           "",
-                                                           "JSON Files ("
-                                                           "*.json);;All "
-                                                           "Files (*)",
-                                                           options=options)
-            if not selected_file:
-                return
-            self.fname_json = selected_file
-        display_name = QFileInfo(self.fname_json).fileName()
-        # Add the display name to the combobox only if it doesn't already exist
-        if display_name not in [self.ui.cbb_fit_model_list.itemText(i) for i in
-                                range(self.ui.cbb_fit_model_list.count())]:
-            self.ui.cbb_fit_model_list.addItem(display_name)
-            self.ui.cbb_fit_model_list.setCurrentText(display_name)
-        else:
-            show_alert('Fit model is already available in the model list')
-
-    def get_loaded_fit_model(self):
-        """Define loaded fit model"""
-        if self.ui.cbb_fit_model_list.currentIndex() == -1:
+    def get_fit_model(self):
+        """Get the selected fit model from the combobox or last loaded file."""
+        if self.fit_model_manager.combo_models.currentIndex() == -1:
             self.loaded_fit_model = None
             return
-        try:
-            # If the file is not found in the selected path, try finding it
-            # in the default folder
-            folder_path = self.fit_model_manager.default_model_folder
-            model_name = self.ui.cbb_fit_model_list.currentText()
-            path = os.path.join(folder_path, model_name)
-            self.loaded_fit_model = self.spectrums.load_model(path, ind=0)
-        except FileNotFoundError:
-            try:
-                self.loaded_fit_model = self.spectrums.load_model(
-                    self.fname_json, ind=0)
-            except FileNotFoundError:
-                show_alert('Fit model file not found in the default folder.')
+        
+        model_name = self.fit_model_manager.combo_models.currentText()
+        folder_path = self.fit_model_manager.default_model_folder
+        path_in_folder = os.path.join(folder_path, model_name)
+    
+        # Try default folder first
+        if os.path.exists(path_in_folder):
+            self.loaded_fit_model = self.spectrums.load_model(path_in_folder, ind=0)
+            return
+
+        # Fallback: ask user to load a file if not found in default folder
+        loaded_model_path = self.fit_model_manager.loaded_fit_model
+        if loaded_model_path and os.path.exists(loaded_model_path):
+            self.loaded_fit_model = self.spectrums.load_model(loaded_model_path, ind=0)
+            return
+        
+        # If all fails
+        show_alert('Fit model file not found')
+        self.loaded_fit_model = None
 
     def save_fit_model(self):
-        """Save the fit model of the selected spectrum."""
+        """Save the fit model of the currently selected spectrum to a JSON file."""
+
         sel_spectrum, sel_spectra = self.get_spectrum_object()
         path = self.fit_model_manager.default_model_folder
         save_path, _ = QFileDialog.getSaveFileName(
             self.ui.tabWidget, "Save fit model", path,
             "JSON Files (*.json)")
+        
         if save_path and sel_spectrum:
             self.spectrums.save(save_path, [sel_spectrum.fname])
             show_alert("Fit model is saved (JSON file)")
         else:
             print("Nothing is saved.")
-        self.upd_model_cbb_list()
+
+        self.fit_model_manager.scan_and_udp_model_cbb() # Update model list in combobox
+
 
     def read_x_range(self):
         """Read x range of selected spectrum"""
         sel_spectrum, sel_spectra = self.get_spectrum_object()
-        self.ui.range_min.setText(str(sel_spectrum.x[0]))
-        self.ui.range_max.setText(str(sel_spectrum.x[-1]))
+        xmin = round(sel_spectrum.x[0], 3)
+        xmax = round(sel_spectrum.x[-1], 3)
+        self.ui.range_min.setText(str(xmin))
+        self.ui.range_max.setText(str(xmax))
 
     def set_x_range(self, fnames=None):
         """Sets a new x-axis range for the selected spectrum(s)"""
@@ -448,7 +367,10 @@ class Maps(QObject):
         if fnames is None:
             map_name, coords = self.spectra_id()
             fnames = [f"{map_name}_{coord}" for coord in coords]
-        self.common.reinit_spectrum(fnames, self.spectrums)
+        
+        for fname in fnames:
+            self.spectrums.get_objects(fname)[0].reinit()
+        
         for fname in fnames:
             spectrum, _ = self.spectrums.get_objects(fname)
             spectrum.range_min = float(self.ui.range_min.text())
@@ -459,7 +381,7 @@ class Maps(QObject):
             spectrum.x = spectrum.x0[ind_min:ind_max + 1].copy()
             spectrum.y = spectrum.y0[ind_min:ind_max + 1].copy()
         QTimer.singleShot(50, self.upd_spectra_list)
-        QTimer.singleShot(300, self.spectra_widget.rescale)
+        QTimer.singleShot(300, self.spectra_viewer.rescale)
 
     def set_x_range_all(self):
         """Set new x range for all spectrum"""
@@ -509,7 +431,7 @@ class Maps(QObject):
                 continue
         QTimer.singleShot(50, self.refresh_gui)
         QTimer.singleShot(100, self.upd_spectra_list)
-        QTimer.singleShot(300, self.spectra_widget.rescale)
+        QTimer.singleShot(300, self.spectra_viewer.rescale)
 
     def subtract_baseline_all(self):
         """Subtracts baseline points for all spectra"""
@@ -523,11 +445,13 @@ class Maps(QObject):
         """Get all settings for the fitting action."""
         sel_spectrum, sel_spectra = self.get_spectrum_object()
         fit_params = sel_spectrum.fit_params.copy()
-        fit_params['fit_negative'] = self.ui.cb_fit_negative.isChecked()
-        fit_params['max_ite'] = self.ui.max_iteration.value()
-        fit_params['method'] = self.ui.cbb_fit_methods.currentText()
-        fit_params['ncpu'] = self.ui.ncpu.value()
-        fit_params['xtol'] = float(self.ui.xtol.text())
+        
+        fit_params['fit_negative'] = self.settings.value("fit_settings/fit_negative", False, type=bool)
+        fit_params['max_ite'] = self.settings.value("fit_settings/max_ite", 200, type=int)
+        fit_params['method'] = self.settings.value("fit_settings/method", "Leastsq")
+        fit_params['ncpu'] = self.settings.value("fit_settings/ncpu", 1, type=int)
+        fit_params['xtol'] = self.settings.value("fit_settings/xtol", 1e-4, type=float)
+        
         sel_spectrum.fit_params = fit_params
 
     def fit(self, fnames=None):
@@ -574,28 +498,29 @@ class Maps(QObject):
         sel_spectrum, _ = self.get_spectrum_object()
         if len(sel_spectrum.peak_models) == 0:
             self.ui.lbl_copied_fit_model.setText("")
-            msg = ("Select spectrum is not fitted or No fit results to collect")
-            show_alert(msg)
-            self.current_fit_model = None
+            msg = ("No fit results to collect or copy")
+            print(msg)
+            self.copied_fit_model = None
             return
         else:
-            self.current_fit_model = None
-            self.current_fit_model = deepcopy(sel_spectrum.save())
+            self.copied_fit_model = None
+            self.copied_fit_model = deepcopy(sel_spectrum.save())
         self.ui.lbl_copied_fit_model.setText("copied")
 
     def paste_fit_model(self, fnames=None):
         """Apply the copied fit model to selected spectra."""
-
         self.ui.centralwidget.setEnabled(False)  # Disable GUI
         if fnames is None:
             map_name, coords = self.spectra_id()
             fnames = [f"{map_name}_{coord}" for coord in coords]
 
-        self.common.reinit_spectrum(fnames, self.spectrums)
-        fit_model = deepcopy(self.current_fit_model)
+        for fname in fnames:
+            self.spectrums.get_objects(fname)[0].reinit()
+            
+        fit_model = deepcopy(self.copied_fit_model)
 
         self.ntot = len(fnames)
-        ncpu = int(self.ui.ncpu.text())
+        ncpu = self.settings.value("fit_settings/ncpu", 1, type=int)
 
         if fit_model is not None:
             self.spectrums.pbar_index = 0
@@ -619,11 +544,11 @@ class Maps(QObject):
         
     def paste_peaks(self, sel_spectra=None):
         """Copy and paste only peak labels and peak models to the selected spectra."""
-        if not self.current_fit_model:
+        if not self.copied_fit_model:
             show_alert("No fit model copied")
             return
         # Extract data from the correct location
-        fit_data = self.current_fit_model
+        fit_data = self.copied_fit_model
         
         self.current_peaks = {
             "peak_labels": fit_data.get("peak_labels", []),
@@ -648,7 +573,7 @@ class Maps(QObject):
 
     def apply_loaded_fit_model(self, fnames=None):
         """Fit selected spectrum(s) with the loaded fit model."""
-        self.get_loaded_fit_model()
+        self.get_fit_model()
         self.ui.centralwidget.setEnabled(False)  # Disable GUI
         if self.loaded_fit_model is None:
             show_alert("Select from the list or load a fit model.")
@@ -660,7 +585,7 @@ class Maps(QObject):
             fnames = [f"{map_name}_{coord}" for coord in coords]
 
         self.ntot = len(fnames)
-        ncpu = int(self.ui.ncpu.text())
+        ncpu = self.settings.value("fit_settings/ncpu", 1, type=int)
         fit_model = self.loaded_fit_model
         spectra = self.spectrums
         self.spectrums.pbar_index = 0
@@ -689,7 +614,7 @@ class Maps(QObject):
     def fit_completed(self):
         """Update GUI after completing fitting process."""
         self.upd_spectra_list()
-        QTimer.singleShot(200, self.spectra_widget.rescale)
+        QTimer.singleShot(200, self.spectra_viewer.rescale)
         self.ui.progressBar.setValue(100)
         self.ui.centralwidget.setEnabled(True)
 
@@ -766,13 +691,12 @@ class Maps(QObject):
         self.df_fit_results = dfr
         self.df_table.show(self.df_fit_results)
 
-
-
     def reinit(self, fnames=None):
         """Reinitialize the selected spectrum(s)."""
         if fnames is None:
             map_name, coords = self.spectra_id()
             fnames = [f"{map_name}_{coord}" for coord in coords]
+       
         else:
             # Extract map_name and coords from fnames
             map_name = None
@@ -782,24 +706,15 @@ class Maps(QObject):
                 if map_name is None:
                     map_name = parts[0]  # Assume map_name is the first part
                 coords.append('_'.join(parts[1:]))
-            
-        # selected_spectrums = []
-        # for spectrum in self.spectrums:
-        #     map_name_fs, coord_fs = self.spectrum_object_id(spectrum)
-            
-        #     if map_name_fs == map_name and coord_fs in coords:
-        #         selected_spectrums.append(spectrum)
+    
+        for fname in fnames:
+            self.spectrums.get_objects(fname)[0].reinit()
 
-        # # Restore spectrums if they were x-range corrected
-        # self.undo_xrange_correction(selected_spectrums)
-
-        self.common.reinit_spectrum(fnames, self.spectrums)
         self.upd_spectra_list()
-        QTimer.singleShot(200, self.spectra_widget.rescale)
+        QTimer.singleShot(200, self.spectra_viewer.rescale)
 
     def reinit_all(self):
         """Reinitialize all spectra"""
-        # self.undo_xrange_correction(self.spectrums)
         fnames = self.spectrums.fnames
         self.reinit(fnames)
 
@@ -819,16 +734,17 @@ class Maps(QObject):
         if not selected_spectrums:
             return
 
-        self.spectra_widget.plot(selected_spectrums)
+        self.spectra_viewer.plot(selected_spectrums)
         
         df = self.maps.get(map_name)
-        self.map_plot.map_df_name=map_name
-        self.map_plot.map_df=df
-        self.map_plot.plot(coords)
+        
+        self.map_viewer.map_df_name=map_name
+        self.map_viewer.map_df=df
+        self.map_viewer.plot(coords)
 
         # Show correction value of the last selected item
-        correction_value = round(selected_spectrums[-1].correction_value, 3)
-        text = f"[{correction_value}]"
+        xcorrection_value = round(selected_spectrums[-1].xcorrection_value, 3)
+        text = f"[{xcorrection_value}]"
         self.ui.lbl_correction_value_2.setText(text)
 
         self.read_x_range()
@@ -842,15 +758,15 @@ class Maps(QObject):
         map_df = self.maps.get(map_name)
 
         if map_df is not None:
-            self.map_plot.map_df_name=map_name
-            self.map_plot.map_df=map_df
+            self.map_viewer.map_df_name=map_name
+            self.map_viewer.map_df=map_df
             column_labels = map_df.columns[2:-1].astype(float)
             
-            current_min, current_max = self.map_plot.x_range_slider.value()
+            current_min, current_max = self.map_viewer.x_range_slider.value()
             min_value = float(column_labels.min())
             max_value = float(column_labels.max())
             
-            self.map_plot.update_xrange_slider(min_value, max_value, current_min, current_max)
+            self.map_viewer.update_xrange_slider(min_value, max_value, current_min, current_max)
 
         checked_states = {}
         for index in range(self.ui.spectra_listbox.count()):
@@ -939,15 +855,15 @@ class Maps(QObject):
         map_name, coords = self.spectra_id()
         if map_name in self.maps:
             del self.maps[map_name]
-            self.spectrums = CustomizedSpectra(
+            self.spectrums = Spectra(
                 spectrum for spectrum in self.spectrums if
                 not spectrum.fname.startswith(map_name))
             self.upd_maps_list()
         self.ui.spectra_listbox.clear()
-        self.spectra_widget.sel_spectrums = None  
-        self.spectra_widget.refresh_plot() 
-        self.map_plot.ax.clear()
-        self.map_plot.canvas.draw_idle()
+        self.spectra_viewer.sel_spectrums = None  
+        self.spectra_viewer.refresh_plot() 
+        self.map_viewer.ax.clear()
+        self.map_viewer.canvas.draw_idle()
 
     def select_all_spectra(self):
         """Select all spectra listed in the spectra listbox"""
@@ -1010,14 +926,7 @@ class Maps(QObject):
             return None, None
 
     def spectra_id(self):
-        """
-        Get selected spectra IDs from the GUI Maps and spectra listboxes.
-
-        Returns:
-        - map_name: Name of the selected maps.
-        - coords: List of selected spectrum coordinates.
-
-        """
+        """Get selected spectra IDs from the GUI Maps and spectra listboxes"""
         map_item = self.ui.maps_listbox.currentItem()
         if map_item is not None:
             map_name = map_item.text()
@@ -1033,14 +942,7 @@ class Maps(QObject):
         return None, None
 
     def spectrum_object_id(self, spectrum=None):
-        """
-        Get the ID of a selected spectrum from a fitspy spectra object.
-
-        Returns:
-        - map_name_fs: Map name extracted from the spectrum object.
-        - coord_fs: Coordinates extracted from the spectrum object.
-
-        """
+        """Get the ID of a selected spectrum from a fitspy spectra object."""
         fname_parts = spectrum.fname.split("_")
         map_name_fs = "_".join(fname_parts[:-1])
         coord_str = fname_parts[-1]  # Last part contains the coordinates
@@ -1060,28 +962,28 @@ class Maps(QObject):
     def send_df_to_viz(self):
         """Send the collected spectral data dataframe to the visualization
         tab."""
-        dfs_new = self.visu.original_dfs
+        dfs_new = self.graphs.original_dfs
         df_name = self.ui.ent_send_df_to_viz2.text()
         
         dfs_new[df_name] = self.df_fit_results
-        self.visu.open_dfs(dfs=dfs_new, file_paths=None)
+        self.graphs.open_dfs(dfs=dfs_new, file_paths=None)
     
     def plot_extracted_profile(self):
         """Extract profile from map plot and Plot in VIS TAB"""
         
-        profile_name = self.map_plot.profile_name.text()
-        profil_df = self.map_plot.extract_profile()
+        profile_name = self.map_viewer.profile_name.text()
+        profil_df = self.map_viewer.extract_profile()
         
         if profil_df is not None and profile_name is not None:
-            dfs_new = self.visu.original_dfs
+            dfs_new = self.graphs.original_dfs
             dfs_new[profile_name] = profil_df
-            self.visu.open_dfs(dfs=dfs_new, file_paths=None)
+            self.graphs.open_dfs(dfs=dfs_new, file_paths=None)
 
             #Add a line plot
-            available_ids = [i for i in range(1, len(self.visu.plots) + 2) if i not in self.visu.plots]
-            graph_id = min(available_ids) if available_ids else len(self.visu.plots) + 1
+            available_ids = [i for i in range(1, len(self.graphs.plots) + 2) if i not in self.graphs.plots]
+            graph_id = min(available_ids) if available_ids else len(self.graphs.plots) + 1
             graph = Graph(graph_id=graph_id)
-            self.visu.plots[graph.graph_id] = graph
+            self.graphs.plots[graph.graph_id] = graph
 
             graph.plot_style='line'
             graph.df_name = profile_name
@@ -1089,7 +991,7 @@ class Maps(QObject):
             graph.y = ['values']
             graph.z = None
             graph.create_plot_widget(100)
-            graph_dialog = QDialog(self.visu)
+            graph_dialog = QDialog(self.graphs)
             layout = QVBoxLayout()
             layout.setContentsMargins(0, 0, 0, 0)
             layout.addWidget(graph)
@@ -1099,19 +1001,19 @@ class Maps(QObject):
             # Add the QDialog to a QMdiSubWindow
             sub_window = MdiSubWindow(graph_id, self.ui.lbl_figsize,mdi_area=self.ui.mdiArea)
             sub_window.setWidget(graph_dialog)
-            sub_window.closed.connect(self.visu.delete_graph)
+            sub_window.closed.connect(self.graphs.delete_graph)
             sub_window.resize(graph.plot_width, graph.plot_height)
             self.ui.mdiArea.addSubWindow(sub_window)
             sub_window.show()
-            self.visu.add_graph_list_to_combobox()
+            self.graphs.add_graph_list_to_combobox()
             text = f"{graph.graph_id}-{graph.plot_style}_plot: {{'distance'}} - {{'values'}} - {{'None'}}"
             graph_dialog.setWindowTitle(text)
             # Plot action
-            QTimer.singleShot(100, self.visu.plot_action)
-            QTimer.singleShot(200, self.visu.customize_legend)
+            QTimer.singleShot(100, self.graphs._plot_action)
+            QTimer.singleShot(200, self.graphs.customize_legend)
             self.ui.tabWidget.setCurrentWidget(self.ui.tab_graphs)
 
-            self.map_plot.options_menu.close() #Close option menu
+            self.map_viewer.options_menu.close() #Close option menu
         else:
             msg="Profile extraction failed or insufficient points selected."
             show_alert(msg)
@@ -1151,7 +1053,7 @@ class Maps(QObject):
         if spectrum.result_fit:
             try:
                 text = fit_report(spectrum.result_fit)
-                self.common.view_text(ui, title, text)
+                view_text(ui, title, text)
             except:
                 return
 
@@ -1272,7 +1174,7 @@ class Maps(QObject):
             with open(file_path, 'r') as f:
                 load = json.load(f)
                 try:
-                    self.spectrums = CustomizedSpectra()
+                    self.spectrums = Spectra()
                     self.maps = {}
                     # Decode hex and decompress the dataframe
                     for k, v in load.get('maps', {}).items():
@@ -1299,9 +1201,9 @@ class Maps(QObject):
         """Clear the environment and reset the application state"""
         # Clear loaded maps and spectra
         self.maps.clear()
-        self.spectrums = CustomizedSpectra()
+        self.spectrums = Spectra()
         self.loaded_fit_model = None
-        self.current_fit_model = None
+        self.copied_fit_model = None
         self.df_fit_results = None
 
         # Clear UI elements that display data
@@ -1310,17 +1212,17 @@ class Maps(QObject):
         self.ui.item_count_label.setText("0 points")
 
         # Clear spectra plot view and reset selected spectrums
-        self.spectra_widget.sel_spectrums = None 
-        self.spectra_widget.refresh_plot()
+        self.spectra_viewer.sel_spectrums = None 
+        self.spectra_viewer.refresh_plot()
 
         # Clear plot ofmeasurement sites 
-        self.map_plot.ax.clear()
-        self.map_plot.canvas.draw()
+        self.map_viewer.ax.clear()
+        self.map_viewer.canvas.draw()
 
         self.df_table.clear()
         self.peak_table.clear()
         
         # Refresh the UI to reflect the cleared state
-        QTimer.singleShot(50, self.spectra_widget.rescale)
+        QTimer.singleShot(50, self.spectra_viewer.rescale)
         QTimer.singleShot(100, self.upd_maps_list)
         print("'Maps' Tab environment has been cleared.")
