@@ -4,57 +4,49 @@ import time
 import numpy as np
 import pandas as pd
 import json
-
-from spectroview.components.utils import view_df, show_alert, spectrum_to_dict, dict_to_spectrum, baseline_to_dict, dict_to_baseline, populate_spectrum_listbox, save_df_to_excel, calc_area
-from spectroview.components.utils import FitThread, FitModelManager, CustomizedListWidget, CustomizedSpectra
-from spectroview.components.widget_df_table import DataframeTableWidget
-from spectroview.components.widget_peaktable import PeakTableWidget
-from spectroview.components.widget_spectraview import SpectraViewWidget
-
-from spectroview import FIT_METHODS
-
 from copy import deepcopy
 from pathlib import Path
-from lmfit import fit_report
 
-from fitspy.core.spectrum import Spectrum
+from spectroview.modules.utils import view_df, show_alert, spectrum_to_dict, dict_to_spectrum, baseline_to_dict, dict_to_baseline, populate_spectrum_listbox, save_df_to_excel, calc_area, replace_peak_labels
+
+from spectroview.modules.utils import FitThread, CustomizedListWidget, Spectra, Spectrum
+from spectroview.modules.df_table import DataframeTable
+from spectroview.modules.peak_table import PeakTable
+from spectroview.modules.spectra_viewer import SpectraViewer
+from spectroview.modules.fit_model_manager import FitModelManager
+
+from lmfit import fit_report
 from fitspy.core.utils import closest_index
 
 from PySide6.QtWidgets import QFileDialog, QMessageBox, QApplication
 from PySide6.QtCore import Qt, QFileInfo, QTimer, QObject
 
 class Spectrums(QObject):
-    """
-    Class manages the GUI interactions and operations related to spectra
-    fittings,
-    and visualization of fitted data within "SPACTRA" TAB of the application.
-    """
-
-    def __init__(self, settings, ui, common, visu, app_settings):
+    """Class manages the GUI interactions of Spectra Tab"""
+    def __init__(self, settings, ui, graphs):
         super().__init__()
         self.settings = settings
-        self.app_settings=app_settings
+
         self.ui = ui
-        self.common = common
-        self.visu = visu
+        self.graphs = graphs
 
         self.loaded_fit_model = None
-        self.current_fit_model = None
-        self.current_peaks = None
-        self.spectrums = CustomizedSpectra()
+        self.copied_fit_model = None
+        self.current_peaks = None #Current peaks available of a given spectrum
+        self.spectrums = Spectra()
 
         # Initialize SpectraViewWidget
-        self.spectra_widget = SpectraViewWidget(self)
-        self.ui.fig_canvas_layout.addWidget(self.spectra_widget.canvas)
-        self.ui.toolbar_layout.addWidget(self.spectra_widget.control_widget) 
+        self.spectra_viewer = SpectraViewer(self)
+        self.ui.fig_canvas_layout.addWidget(self.spectra_viewer.canvas)
+        self.ui.toolbar_layout.addWidget(self.spectra_viewer.control_widget) 
         self.ui.cbb_fit_models_2.currentIndexChanged.connect(self.update_peak_model)
         
         # Initialize Peak Table
-        self.peak_table = PeakTableWidget(self, self.ui.peak_table1_2, self.ui.cbb_layout)
+        self.peak_table = PeakTable(self, self.ui.peak_table1_2, self.ui.cbb_layout)
         
         # Initialize Dataframe Table
         self.df_fit_results = None
-        self.df_table = DataframeTableWidget(self.ui.layout_df_table2)
+        self.df_table = DataframeTable(self.ui.layout_df_table2)
 
         # Initialize QListWidget for spectra list
         self.ui.spectrums_listbox = CustomizedListWidget()
@@ -68,25 +60,19 @@ class Spectrums(QObject):
         self.delay_timer.setSingleShot(True)
         self.delay_timer.timeout.connect(self.plot)
         
-        self.ui.cbb_fit_methods_2.addItems(FIT_METHODS)
         self.ui.btn_send_to_viz.clicked.connect(self.send_df_to_viz)
 
-        # Load default folder path
-        self.fit_model_manager = FitModelManager(self.settings)
-        self.fit_model_manager.default_model_folder = self.settings.value(
-            "default_model_folder", "")
-        self.ui.l_defaut_folder_model_3.setText(
-            self.fit_model_manager.default_model_folder)
-        QTimer.singleShot(0, self.populate_available_models)
-        self.ui.btn_refresh_model_folder_3.clicked.connect(
-            self.populate_available_models)
-        
         # Peak correction
         self.ui.btn_xrange_correction.clicked.connect(self.xrange_correction)
         self.ui.btn_undo_correction.clicked.connect(lambda: self.undo_xrange_correction())
 
         # BASELINE
         self.setup_baseline_controls()
+        
+        # FIT MODEL MANAGER
+        self.fit_model_manager = FitModelManager()
+        self.ui.horizontalLayout_106.addWidget(self.fit_model_manager)
+        self.fit_model_manager.connect_apply(self.apply_model_fnc_handler)
 
     def setup_baseline_controls(self):
         """Set up baseline controls and their signal connections."""
@@ -111,7 +97,7 @@ class Spectrums(QObject):
         """Open and load raw spectral data"""
 
         if self.spectrums is None:
-            self.spectrums = CustomizedSpectra()
+            self.spectrums = Spectra()
         if spectra:
             self.spectrums = spectra
         else:
@@ -152,9 +138,6 @@ class Spectrums(QObject):
                     spectrum.y = np.asarray(y_values)
                     spectrum.y0 = np.asarray(y_values)
 
-                    spectrum.is_corrected = False
-                    spectrum.correction_value = 0   
-
                     spectrum.baseline.mode = "Linear"
                     spectrum.baseline.sigma = 10
                     self.spectrums.append(spectrum)
@@ -169,38 +152,23 @@ class Spectrums(QObject):
             ref_value = round(float(text), 3)                
             if sel_spectra is None:
                 _, sel_spectra = self.get_spectrum_object()
-            
-            # Restore to original values
-            self.undo_xrange_correction(sel_spectra)
+               
             for spectrum in sel_spectra:
-                # Correction action
-                correction_value = (520.7 - ref_value)
-                uncorrectted_x = deepcopy(spectrum.x)
-                uncorrectted_x0 = deepcopy(spectrum.x0)
-                spectrum.x = uncorrectted_x + correction_value
-                spectrum.x0 = uncorrectted_x0 + correction_value
-                spectrum.correction_value = correction_value
-                spectrum.is_corrected = True
-
+                new_xcorrection_value = 520.7 - ref_value
+                print(f"Applying x range correction of {new_xcorrection_value} for spectrum {spectrum.fname}")
+                spectrum.apply_xcorrection(new_xcorrection_value)
             QTimer.singleShot(100, self.upd_spectra_list)
 
         except ValueError:
             QMessageBox.warning(self.ui.tabWidget, "Input Error", "Please enter a valid numeric Si peak reference.")
-
     
     def undo_xrange_correction(self, sel_spectra=None):
         """Undo peak shift correction for the given spectra."""
         if sel_spectra is None:
             _, sel_spectra = self.get_spectrum_object()
         for spectrum in sel_spectra:
-            if spectrum.is_corrected:
-                # Restore original X values
-                correctted_x=deepcopy(spectrum.x)
-                correctted_x0=deepcopy(spectrum.x0)
-                spectrum.x = correctted_x - spectrum.correction_value
-                spectrum.x0 = correctted_x0 - spectrum.correction_value
-                spectrum.correction_value = 0
-                spectrum.is_corrected = False
+            spectrum.undo_xcorrection()
+
         QTimer.singleShot(100, self.upd_spectra_list)       
         
     def copy_fit_model(self):
@@ -210,26 +178,29 @@ class Spectrums(QObject):
         sel_spectrum, _ = self.get_spectrum_object()
         if len(sel_spectrum.peak_models) == 0:
             self.ui.lbl_copied_fit_model_2.setText("")
-            msg = ("There are no fitted peaks")
-            show_alert(msg)
-            self.current_fit_model = None
+            msg = ("No fit results to collect or copy")
+            print(msg)
+            self.copied_fit_model = None
             return
         else:
-            self.current_fit_model = None
-            self.current_fit_model = deepcopy(sel_spectrum.save())
+            self.copied_fit_model = None
+            self.copied_fit_model = deepcopy(sel_spectrum.save())
         self.ui.lbl_copied_fit_model_2.setText("copied")     
 
     def paste_fit_model(self, fnames=None):
         """Apply the copied fit model to the selected spectra"""
         self.ui.centralwidget.setEnabled(False)  # Disable GUI
         
-        if fnames is None:
-            fnames = self.get_spectrum_fnames()
+        fnames = fnames or self.get_spectrum_fnames()
+            
+        for fname in fnames:
+            spectrum, _ = self.spectrums.get_objects(fname)
+            spectrum.reinit()
             
-        self.common.reinit_spectrum(fnames, self.spectrums)
         self.ntot = len(fnames)
-        fit_model = deepcopy(self.current_fit_model)
-        ncpu = int(self.ui.ncpu_2.text())
+        fit_model = deepcopy(self.copied_fit_model)
+        
+        ncpu = self.settings.value("fit_settings/ncpu", 1, type=int)
 
         if fit_model is not None:
             self.spectrums.pbar_index = 0
@@ -248,11 +219,11 @@ class Spectrums(QObject):
         
     def paste_peaks(self, sel_spectra=None):
         """Copy and paste only peak labels and peak models to the selected spectra."""
-        if not self.current_fit_model:
+        if not self.copied_fit_model:
             show_alert("No fit model copied")
             return
         # Extract data from the correct location
-        fit_data = self.current_fit_model
+        fit_data = self.copied_fit_model
         
         self.current_peaks = {
             "peak_labels": fit_data.get("peak_labels", []),
@@ -279,8 +250,8 @@ class Spectrums(QObject):
     def fit(self, fnames=None):
         """Fit the selected spectrum(s) with current parameters"""
         self.get_fit_settings()
-        if fnames is None:
-            fnames = self.get_spectrum_fnames()
+        fnames = fnames or self.get_spectrum_fnames()
+            
         for fname in fnames:
             spectrum, _ = self.spectrums.get_objects(fname)
             if len(spectrum.peak_models) != 0:
@@ -296,8 +267,10 @@ class Spectrums(QObject):
         self.fit(fnames)
 
     def apply_loaded_fit_model(self, fnames=None):
+        
         """Apply the loaded fit model to selected spectra"""
-        self.get_loaded_fit_model()
+        self.get_fit_model()
+
         self.ui.centralwidget.setEnabled(False)  # Disable GUI
         if self.loaded_fit_model is None:
             show_alert("Select from the list or load a fit model.")
@@ -308,7 +281,7 @@ class Spectrums(QObject):
             fnames = self.get_spectrum_fnames()
 
         self.ntot = len(fnames)
-        ncpu = int(self.ui.ncpu_2.text())
+        ncpu = self.settings.value("fit_settings/ncpu", 1, type=int)
         fit_model = self.loaded_fit_model
         self.spectrums.pbar_index = 0
 
@@ -336,7 +309,7 @@ class Spectrums(QObject):
     def fit_completed(self):
         """Update GUI after completing fitting process."""
         self.upd_spectra_list()
-        QTimer.singleShot(200,  self.spectra_widget.rescale)
+        QTimer.singleShot(200,  self.spectra_viewer.rescale)
         self.ui.progressBar_2.setValue(100)
         self.ui.centralwidget.setEnabled(True)
 
@@ -347,8 +320,6 @@ class Spectrums(QObject):
         fnames = checked_spectra.fnames
         self.apply_loaded_fit_model(fnames=fnames)
 
-    
-
     def upd_spectra_list(self):
         """Show spectrums in a listbox"""
         # Store the checked state of each item
@@ -358,8 +329,8 @@ class Spectrums(QObject):
             checked_states[item.text()] = item.checkState()
 
         current_row = self.ui.spectrums_listbox.currentRow()
-        current_selection = [self.ui.spectrums_listbox.item(i).text() for i in range(self.ui.spectrums_listbox.count()) if self.ui.spectrums_listbox.item(i).isSelected()]
-        
+        current_selection = {item.text() for item in self.ui.spectrums_listbox.selectedItems()}
+
         self.ui.spectrums_listbox.clear()
         
         for spectrum in self.spectrums:
@@ -391,17 +362,17 @@ class Spectrums(QObject):
         """Plot spectra or fit results in the main plot area."""
         fnames = self.get_spectrum_fnames()
         
-        selected_spectrums = CustomizedSpectra()
+        selected_spectrums = Spectra()
         selected_spectrums = [spectrum for spectrum in self.spectrums if spectrum.fname in fnames]
         # Limit the number of spectra to avoid crashes
         selected_spectrums = selected_spectrums[:30]
         if not selected_spectrums:
             return
-        self.spectra_widget.plot(selected_spectrums)
+        self.spectra_viewer.plot(selected_spectrums)
 
         # Show correction value of the last selected item
-        correction_value = round(selected_spectrums[-1].correction_value, 3)
-        text = f"[{correction_value}]"
+        xcorrection_value = round(selected_spectrums[-1].xcorrection_value, 3)
+        text = f"[{xcorrection_value}]"
         self.ui.lbl_correction_value.setText(text)
         
         self.read_x_range()
@@ -415,7 +386,7 @@ class Spectrums(QObject):
         """
         Get a list of selected spectra based on listbox's checkbox states.
         """
-        checked_spectra = CustomizedSpectra()
+        checked_spectra = Spectra()
         for index in range(self.ui.spectrums_listbox.count()):
             item = self.ui.spectrums_listbox.item(index)
             if item.checkState() == Qt.Checked:
@@ -453,106 +424,52 @@ class Spectrums(QObject):
         self.spectrums.clear()
         self.spectrums.extend(new_order)
 
-
-    def set_default_model_folder(self, folder_path=None):
-        """
-        Set the default folder where contain fit_models.
-        """
-        if not folder_path:
-            folder_path = QFileDialog.getExistingDirectory(None,
-                                                           "Select Default "
-                                                           "Folder",
-                                                           options=QFileDialog.ShowDirsOnly)
-        if folder_path:
-            self.fit_model_manager.set_default_model_folder(folder_path)
-            # Save selected folder path back to QSettings
-            self.settings.setValue("default_model_folder", folder_path)
-            self.ui.l_defaut_folder_model_3.setText(
-                self.fit_model_manager.default_model_folder)
-            QTimer.singleShot(0, self.populate_available_models)
-            
     def update_peak_model(self):
-        """Update the peak model in the SpectraViewWidget based on combobox selection."""
+        """Update the peak model in the Spectra viewer based on combobox selection."""
         selected_model = self.ui.cbb_fit_models_2.currentText()
-        self.spectra_widget.set_peak_model(selected_model)
+        self.spectra_viewer.set_peak_model(selected_model)
 
-    def upd_model_cbb_list(self):
-        """Update and populate the model list in the UI combobox"""
-        current_path = self.fit_model_manager.default_model_folder
-        self.set_default_model_folder(current_path)
 
-    def populate_available_models(self):
-        """Populate the available fit models in the UI combobox"""
-        self.fit_model_manager.scan_models()
-        self.available_models = self.fit_model_manager.get_available_models()
-        self.ui.cbb_fit_model_list_3.clear()
-        self.ui.cbb_fit_model_list_3.addItems(self.available_models)
-
-    def load_fit_model(self, fname_json=None):
-        """
-        Load a fit model from a JSON file or from the UI selection.
-        """
-        self.fname_json = fname_json
-        self.upd_model_cbb_list()
-        if not fname_json:
-            options = QFileDialog.Options()
-            options |= QFileDialog.ReadOnly
-            selected_file, _ = QFileDialog.getOpenFileName(self.ui,
-                                                           "Select JSON Model "
-                                                           "File",
-                                                           "",
-                                                           "JSON Files ("
-                                                           "*.json);;All "
-                                                           "Files (*)",
-                                                           options=options)
-            if not selected_file:
-                return
-            self.fname_json = selected_file
-        display_name = QFileInfo(self.fname_json).fileName()
-        # Add the display name to the combobox only if it doesn't already exist
-        if display_name not in [self.ui.cbb_fit_model_list_3.itemText(i) for i
-                                in
-                                range(self.ui.cbb_fit_model_list_3.count())]:
-            self.ui.cbb_fit_model_list_3.addItem(display_name)
-            self.ui.cbb_fit_model_list_3.setCurrentText(display_name)
-        else:
-            show_alert('Fit model is already available in the model list')
-
-    def get_loaded_fit_model(self):
-        """Retrieve the currently loaded fit model from the UI"""
-        if self.ui.cbb_fit_model_list_3.currentIndex() == -1:
+    def get_fit_model(self):
+        """Get the selected fit model from the combobox or last loaded file."""
+        if self.fit_model_manager.combo_models.currentIndex() == -1:
             self.loaded_fit_model = None
             return
-        try:
-            # If the file is not found in the selected path, try finding it
-            # in the default folder
-            folder_path = self.fit_model_manager.default_model_folder
-            model_name = self.ui.cbb_fit_model_list_3.currentText()
-            path = os.path.join(folder_path, model_name)
-            self.loaded_fit_model = self.spectrums.load_model(path, ind=0)
-        except FileNotFoundError:
-            try:
-                self.loaded_fit_model = self.spectrums.load_model(
-                    self.fname_json, ind=0)
-            except FileNotFoundError:
-                show_alert('Fit model file not found in the default folder')
+        
+        model_name = self.fit_model_manager.combo_models.currentText()
+        folder_path = self.fit_model_manager.default_model_folder
+        path_in_folder = os.path.join(folder_path, model_name)
+    
+        # Try default folder first
+        if os.path.exists(path_in_folder):
+            self.loaded_fit_model = self.spectrums.load_model(path_in_folder, ind=0)
+            return
+
+        # Fallback: ask user to load a file if not found in default folder
+        loaded_model_path = self.fit_model_manager.loaded_fit_model
+        if loaded_model_path and os.path.exists(loaded_model_path):
+            self.loaded_fit_model = self.spectrums.load_model(loaded_model_path, ind=0)
+            return
+        
+        # If all fails
+        show_alert('Fit model file not found')
+        self.loaded_fit_model = None
 
     def save_fit_model(self):
-        """
-        Save the fit model of the currently selected spectrum to a JSON file.
-        """
+        """Save the fit model of the currently selected spectrum to a JSON file."""
+
         sel_spectrum, sel_spectra = self.get_spectrum_object()
         path = self.fit_model_manager.default_model_folder
         save_path, _ = QFileDialog.getSaveFileName(
             self.ui.tabWidget, "Save fit model", path,
             "JSON Files (*.json)")
+        
         if save_path and sel_spectrum:
             self.spectrums.save(save_path, [sel_spectrum.fname])
             show_alert("Fit model is saved (JSON file)")
         else:
             print("Nothing is saved.")
-
-        self.upd_model_cbb_list()
+        self.fit_model_manager.scan_and_udp_model_cbb() # Update model list in combobox
 
     def get_spectrum_fnames(self):
         """Get the filenames of currently selected spectra in the UI"""
@@ -593,9 +510,11 @@ class Spectrums(QObject):
         """Set a new x range for the selected spectrum"""
         new_x_min = float(self.ui.range_min_2.text())
         new_x_max = float(self.ui.range_max_2.text())
-        if fnames is None:
-            fnames = self.get_spectrum_fnames()
-        self.common.reinit_spectrum(fnames, self.spectrums)
+        
+        fnames = fnames or self.get_spectrum_fnames()
+        for fname in fnames:
+            self.spectrums.get_objects(fname)[0].reinit()
+
         for fname in fnames:
             spectrum, _ = self.spectrums.get_objects(fname)
             spectrum.range_min = float(self.ui.range_min_2.text())
@@ -607,7 +526,7 @@ class Spectrums(QObject):
             spectrum.y = spectrum.y0[ind_min:ind_max + 1].copy()
             
         QTimer.singleShot(50, self.upd_spectra_list)
-        QTimer.singleShot(300, self.spectra_widget.rescale)
+        QTimer.singleShot(300, self.spectra_viewer.rescale)
 
     def set_x_range_all(self):
         """Set a new x range for all spectra"""
@@ -660,7 +579,7 @@ class Spectrums(QObject):
                 continue
         QTimer.singleShot(50, self.refresh_gui)
         QTimer.singleShot(100, self.upd_spectra_list)
-        QTimer.singleShot(300, self.spectra_widget.rescale)
+        QTimer.singleShot(300, self.spectra_viewer.rescale)
         
     def subtract_baseline_all(self):
         """Subtract the baseline for all spectra"""
@@ -669,8 +588,8 @@ class Spectrums(QObject):
 
     def clear_peaks(self, fnames=None):
         """Clear all existing peak models of the selected spectrum(s)"""
-        if fnames is None:
-            fnames = self.get_spectrum_fnames()
+        fnames = fnames or self.get_spectrum_fnames()
+                    
         for fname in fnames:
             spectrum, _ = self.spectrums.get_objects(fname)
             if len(spectrum.peak_models) != 0:
@@ -689,11 +608,13 @@ class Spectrums(QObject):
         """Retrieve all settings for the fitting action from the GUI"""
         sel_spectrum, sel_spectra = self.get_spectrum_object()
         fit_params = sel_spectrum.fit_params.copy()
-        fit_params['fit_negative'] = self.ui.cb_fit_negative_2.isChecked()
-        fit_params['max_ite'] = self.ui.max_iteration_2.value()
-        fit_params['method'] = self.ui.cbb_fit_methods_2.currentText()
-        fit_params['ncpu'] = self.ui.ncpu_2.value()
-        fit_params['xtol'] = float(self.ui.xtol_2.text())
+        
+        fit_params['fit_negative'] = self.settings.value("fit_settings/fit_negative", False, type=bool)
+        fit_params['max_ite'] = self.settings.value("fit_settings/max_ite", 200, type=int)
+        fit_params['method'] = self.settings.value("fit_settings/method", "Leastsq")
+        fit_params['ncpu'] = self.settings.value("fit_settings/ncpu", 1, type=int)
+        fit_params['xtol'] = self.settings.value("fit_settings/xtol", 1e-4, type=float)
+        
         sel_spectrum.fit_params = fit_params
 
     def paste_fit_model_all(self):
@@ -751,7 +672,7 @@ class Spectrums(QObject):
                 names.append(name)
             self.df_fit_results = self.df_fit_results.iloc[:,list(np.argsort(names, kind='stable'))]
             # Replace peak_label
-            columns = [self.common.replace_peak_labels(self.current_fit_model, column) for column in self.df_fit_results.columns]
+            columns = [replace_peak_labels(self.copied_fit_model, column) for column in self.df_fit_results.columns]
             self.df_fit_results.columns = columns
         
         self.df_table.show(self.df_fit_results)
@@ -809,10 +730,10 @@ class Spectrums(QObject):
 
     def send_df_to_viz(self):
         """Send the collected spectral data to the visualization tab"""
-        dfs_new = self.visu.original_dfs
+        dfs_new = self.graphs.original_dfs
         df_name = self.ui.ent_send_df_to_viz.text()
         dfs_new[df_name] = self.df_fit_results
-        self.visu.open_dfs(dfs=dfs_new, file_paths=None)
+        self.graphs.open_dfs(dfs=dfs_new, file_paths=None)
 
 
     def cosmis_ray_detection(self):
@@ -820,18 +741,13 @@ class Spectrums(QObject):
 
     def reinit(self, fnames=None):
         """Reinitialize the selected spectrum(s)"""
-        if fnames is None:
-            fnames = self.get_spectrum_fnames()
+        fnames = fnames or self.get_spectrum_fnames()
+        
+        for fname in fnames:
+            self.spectrums.get_objects(fname)[0].reinit()
             
-        # selected_spectrums = CustomSpectra()
-        # selected_spectrums = [spectrum for spectrum in self.spectrums if spectrum.fname in fnames]
-        # Restore spectrums if they were x-range corrected
-        # self.undo_xrange_correction(selected_spectrums)
-
-        # Reinit spectrum
-        self.common.reinit_spectrum(fnames, self.spectrums)
         self.upd_spectra_list()
-        QTimer.singleShot(200, self.spectra_widget.rescale)
+        QTimer.singleShot(200, self.spectra_viewer.rescale)
 
     def reinit_all(self):
         """Reinitialize all spectra"""
@@ -887,12 +803,12 @@ class Spectrums(QObject):
 
     def remove_spectrum(self):
         fnames = self.get_spectrum_fnames()
-        self.spectrums = CustomizedSpectra(
+        self.spectrums = Spectra(
             spectrum for spectrum in self.spectrums if
             spectrum.fname not in fnames)
         self.upd_spectra_list()
-        self.spectra_widget.ax.clear()
-        self.spectra_widget.canvas.draw()
+        self.spectra_viewer.ax.clear()
+        self.spectra_viewer.canvas.draw()
 
 
     def fit_fnc_handler(self):
@@ -988,7 +904,7 @@ class Spectrums(QObject):
                 load = json.load(f)
                 try:
                     # Load all spectra
-                    self.spectrums = CustomizedSpectra()
+                    self.spectrums = Spectra()
                     for spectrum_id, spectrum_data in load.get('spectrums', {}).items():
                         spectrum = Spectrum()
                         dict_to_spectrum(spectrum=spectrum, spectrum_data=spectrum_data, is_map=False)
@@ -1005,9 +921,9 @@ class Spectrums(QObject):
 
     def clear_env(self):
         """Clear the environment and reset the application state"""
-        self.spectrums = CustomizedSpectra()
+        self.spectrums = Spectra()
         self.loaded_fit_model = None
-        self.current_fit_model = None
+        self.copied_fit_model = None
         self.df_fit_results = None
 
         # Clear Listbox
@@ -1015,14 +931,14 @@ class Spectrums(QObject):
         self.ui.item_count_label_3.setText("0 points")
 
         # Clear spectra plot view and reset selected spectrums
-        self.spectra_widget.sel_spectrums = None  
-        self.spectra_widget.refresh_plot() 
+        self.spectra_viewer.sel_spectrums = None  
+        self.spectra_viewer.refresh_plot() 
         
         self.df_table.clear()
         self.peak_table.clear()
 
         # Refresh the UI to reflect the cleared state
-        QTimer.singleShot(50, self.spectra_widget.rescale)
+        QTimer.singleShot(50, self.spectra_viewer.rescale)
         QTimer.singleShot(100, self.upd_spectra_list)
         print("'Spectrums' Tab environment has been cleared.")
 
